@@ -67,7 +67,7 @@ class pfdo_med2image(pfdo.pfdo):
         """
         This method does not actually read in any files, but
         exists to preserve the list of files associated with a
-        given input directory. 
+        given input directory.
 
         By preserving and returning this file list, the next
         callback function in this pipeline is able to receive an
@@ -150,7 +150,7 @@ class pfdo_med2image(pfdo.pfdo):
                     else:
                         l_fileToAnalyze.append(nIndex)
             return l_fileToAnalyze
-            
+
         b_status            : bool  = False
         l_fileProbed        : list  = []
         d_inputReadCallback : dict  = {}
@@ -164,24 +164,24 @@ class pfdo_med2image(pfdo.pfdo):
             str_path            = at_data[0]
             d_inputReadCallback = at_data[1]
             l_fileProbed        = d_inputReadCallback['l_fileProbed']
-        
+
         # pudb.set_trace()
         med2image_args                  = self.args.copy()
-        for str_file in l_fileToAnalyze_determine(l_fileProbed):            
+        for str_file in l_fileToAnalyze_determine(l_fileProbed):
             med2image_args['inputDir']      = str_path
             med2image_args['inputFile']     = str_file
             med2image_args['outputDir']     = str_path.replace(
-                                                self.args['inputDir'], 
+                                                self.args['inputDir'],
                                                 self.args['outputDir']
                                             )
             if "nii" in str_file:
                 med2image_args['outputDir'] = os.path.join(med2image_args['outputDir'], str_file)
-                os.mkdir(med2image_args['outputDir'])                                           
+                os.mkdir(med2image_args['outputDir'])
             med2image_ns    = Namespace(**med2image_args)
             imgConverter    = med2image.object_factoryCreate(med2image_ns).C_convert
 
             # At time of dev, the `imgConverter.run()` does not return anything.
-            imgConverter.run()
+            if imgConverter: imgConverter.run()
 
         return {
             'status':           b_status,
@@ -190,33 +190,33 @@ class pfdo_med2image(pfdo.pfdo):
             'd_convert':        d_convert
         }
 
-    def filelist_prune(self, at_data, *args, **kwargs) -> dict:
-        """
-        Given a list of files, possibly prune list by
-        interal self.args['filter'].
-        """
+    # def filelist_prune(self, at_data, *args, **kwargs) -> dict:
+    #     """
+    #     Given a list of files, possibly prune list by
+    #     interal self.args['filter'].
+    #     """
 
-        b_status    : bool      = True
-        l_file      : list      = []
-        str_path    : str       = at_data[0]
-        al_file     : list      = at_data[1]
+    #     b_status    : bool      = True
+    #     l_file      : list      = []
+    #     str_path    : str       = at_data[0]
+    #     al_file     : list      = at_data[1]
 
-        if len(self.args['filter']):
-            al_file = [x for x in al_file if self.args['filter'] in x]
+    #     if len(self.args['filter']):
+    #         al_file = [x for x in al_file if self.args['filter'] in x]
 
-        if len(al_file):
-            al_file.sort()
-            l_file      = al_file
-            b_status    = True
-        else:
-            self.dp.qprint( "No valid files to analyze found in path %s!" %
-                            str_path, comms = 'warn', level = 5)
-            l_file      = None
-            b_status    = False
-        return {
-            'status':   b_status,
-            'l_file':   l_file
-        }
+    #     if len(al_file):
+    #         al_file.sort()
+    #         l_file      = al_file
+    #         b_status    = True
+    #     else:
+    #         self.dp.qprint( "No valid files to analyze found in path %s!" %
+    #                         str_path, comms = 'warn', level = 5)
+    #         l_file      = None
+    #         b_status    = False
+    #     return {
+    #         'status':   b_status,
+    #         'l_file':   l_file
+    #     }
 
     def med2image(self) -> dict:
         """
